aboutsummaryrefslogtreecommitdiff
path: root/ports/esp8266/esp_mphal.h
diff options
context:
space:
mode:
Diffstat (limited to 'ports/esp8266/esp_mphal.h')
-rw-r--r--ports/esp8266/esp_mphal.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/ports/esp8266/esp_mphal.h b/ports/esp8266/esp_mphal.h
index 940ca4727..56d9fa35f 100644
--- a/ports/esp8266/esp_mphal.h
+++ b/ports/esp8266/esp_mphal.h
@@ -34,12 +34,15 @@ struct _mp_print_t;
// Structure for UART-only output via mp_printf()
extern const struct _mp_print_t mp_debug_print;
-extern ringbuf_t input_buf;
-// Call this after putting data to input_buf
+extern ringbuf_t stdin_ringbuf;
+// Call this after putting data to stdin_ringbuf
void mp_hal_signal_input(void);
// Call this when data is available in dupterm object
void mp_hal_signal_dupterm_input(void);
+// This variable counts how many times the UART is attached to dupterm
+extern int uart_attached_to_dupterm;
+
void mp_hal_init(void);
void mp_hal_rtc_init(void);